Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1299)

Unified Diff: media/base/android/media_codec_util.h

Issue 1796393002: Remove Exynos from MediaCodec blacklist. Limit MediaTek blacklist. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Revert hunks. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/base/android/media_codec_util.h
diff --git a/media/base/android/media_codec_util.h b/media/base/android/media_codec_util.h
index 04b83a9937299f67e8b3e80066d508ff436062d5..a6f1336873fe0210d749e5dc694e53198d300591 100644
--- a/media/base/android/media_codec_util.h
+++ b/media/base/android/media_codec_util.h
@@ -66,8 +66,9 @@ class MEDIA_EXPORT MediaCodecUtil {
static bool RegisterMediaCodecUtil(JNIEnv* env);
// Indicates if the vp8 decoder is available on this device.
static bool IsVp8DecoderAvailable();
+ static bool IsVp8EncoderAvailable();
};
} // namespace media
« no previous file with comments | « content/common/gpu/media/android_video_encode_accelerator.cc ('k') | media/base/android/media_codec_util.cc » ('j') | no next file with comments »
@@ -66,8 +66,9 @@ class MEDIA_EXPORT MediaCodecUtil {
static bool RegisterMediaCodecUtil(JNIEnv* env);
- // Indicates if the vp8 decoder is available on this device.
+ // Indicates if the vp8 decoder or encoder is available on this device.
static bool IsVp8DecoderAvailable();

Powered by Google App Engine
This is Rietveld 408576698